API Reference
=============

.. toctree::
   :maxdepth: 2
   :glob:

   distributions/*

.. toctree::
   :glob:
   :maxdepth: 3

   experiments/*

.. toctree::
   :maxdepth: 3
   :glob:

   optimization/*

.. autoclass:: gmmvi.gmmvi_runner.GmmviRunner
   :members:
   :undoc-members:


